@@ -484,6 +484,9 @@ get_displayname_auth(char *displayname, AuthList **authl)
     cp = strchr(displayname, '/');
     if (cp && strncmp (cp, "/unix:", 6) == 0)
       prelen = (cp - displayname);
+    
+    if (strncmp (displayname, "/tmp/launch", 11) == 0)
+        displayname = strrchr(displayname, '/') + 1;
 
     if (!parse_displayname (displayname + ((prelen > 0) ? prelen + 1 : 0),
 			    &family, &host, &dpynum, &scrnum, &rest)) {
@@ -630,21 +633,12 @@ static Bool xauth_locked = False;     /* if has been locked */
 static char *xauth_filename = NULL;
 static volatile Bool dieing = False;
 
-#ifdef RETSIGTYPE /* autoconf AC_TYPE_SIGNAL */
-# define _signal_t RETSIGTYPE
-#else /* Imake */
-#ifdef SIGNALRETURNSINT
-#define _signal_t int
-#else
-#define _signal_t void
-#endif
-#endif /* RETSIGTYPE */
 
 /* poor man's puts(), for under signal handlers */
 #define WRITES(fd, S) (void)write((fd), (S), strlen((S)))
 
 /* ARGSUSED */
-static _signal_t 
+static RETSIGTYPE 
 die(int sig)
 {
     dieing = True;
@@ -655,7 +649,7 @@ die(int sig)
 #endif
 }
 
-static _signal_t 
+static RETSIGTYPE 
 catchsig(int sig)
 {
 #ifdef SYSV
@@ -966,7 +960,7 @@ fprintfhex(register FILE *fp, int len, char *cp)
     char *hex;
 
     hex = bintohex(len, cp);
-    fprintf(fp, hex);
+    fprintf(fp, "%s", hex);
     free(hex);
 }
 
@@ -1506,6 +1500,7 @@ do_extract(char *inputfilename, int lineno, int argc, char **argv)
 
     ed.fp = NULL;
     ed.filename = argv[1];
+    ed.used_stdout = False;
     ed.numeric = (argv[0][0] == 'n');
     ed.nwritten = 0;
     ed.cmd = argv[0];
